==> enterprisemodules-vulnerability-0.5.0.tar.gz: enterprisemodules-vulnerability-0.5.0/lib/puppet/face/vulnerability/list.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

require 'puppet/face'
require 'puppet_x/vulnerability/selection'
require 'puppet_x/vulnerability/config'
require 'facter'
require 'pp'

Puppet::Face.define(:vulnerability, '0.0.1') do
  extend ::Vulnerability::Selection
  extend ::Vulnerability::Config

  def self.print_summary(cve_list, level)
    selected_levels(level).each do |report_level|
      # rubocop: disable Style/FormatStringToken
      puts format('%-28s %-10s', "#{report_level} Vulnerabilities:", "#{cve_list.count { |_k, v| v['severity'] == report_level }} found.")
      # rubocop: enable Style/FormatStringToken
    end
  end

  action(:list) do
    default

    summary 'List detected vulnerabilities'

    description <<-DESC
    puppet-vulnerability
    ====================

    List detected vulnerabilities at a certain severity level and above.#{' '}

    Selected CVE's
    --------------
    When you only want to report on selected CVE's specify the CVE's you want to search for as parameters.

    Level
    -----
    You can specify the level you want to report on. By using the `--level` option. The known levels#{' '}
    in order of severity are:
    - Critical
    - High
    - Medium
    - Low
    - Negligible
    - Unknown

    When you don't specify a level, the default is 'High'. Meaning to list Critical and High CVE's.

    Allow List
    ----------
    When you know about certain CVE's and don;'t want to report on them, you can use the `--allow-list option`.
    When a vulnerability is found and it is on the allow-list, it is not reported.

    DESC

    option '--details', '-d' do
      summary 'List all known details of all found vulnerabilities'
      default_to { false }
    end

    option '--summary', '-s' do
      summary 'List a summary of all found vulnerabilities'
      default_to { false }
    end

    option '--level level', '-l level' do
      summary 'The minimum level of vulnerabilities.'
      default_to { 'High' }
      description <<-DESC
      The minimum level of vulnerabilities you want to report on. All
      found vulnerabilities with the specified level and gigher are reported.
      DESC
    end

    option '--allow-list id,id,id', '-a id,id,id' do
      summary 'The allowed vulnerabilities'
      default_to { '' }
      description <<-DESC
      The vulnerabilities you know and don't want to report.
      DESC
    end

    arguments '<cve_id> <cve_id>'

    when_invoked do |*arguments|
      #
      # First process all options
      #
      options         = arguments.pop
      level           = options[:level]
      allow_list      = options[:allow_list].split(',')
      details         = options[:details]
      summary         = options[:summary]
      #
      # Detect the input
      #
      vulnerabilities = Facter.value('cve_list')
      if vulnerabilities.nil?
        Puppet.err "cve_list fact not (yet) determined. No CVE's found yet."
        exit(1)
      end
      #
      # Check level
      #
      config_level = config_data[:level]
      unless selected_levels(config_level).include?(level)
        Puppet.warning "Requested reporting level '#{level}' lower than configured scanning level '#{config_level}'; reporting will not adequately report not scanned levels."
      end
      #
      # Do requested filtering
      #
      selected_cves = level_selection(vulnerabilities, level)
      selected_cves = filter_cves(selected_cves, allow_list)
      selected_cves = selected_cves.select { |c, _i| arguments.include?(c) } unless arguments.empty?
      if selected_cves.empty?
        exit 0
      else
        pp selected_cves if details
        print_summary(selected_cves, level) if summary
        exit 1
      end
    end
  end
end

==> enterprisemodules-vulnerability-1.5.0.tar.gz: enterprisemodules-vulnerability-1.5.0/lib/puppet/face/vulnerability/list.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

require 'puppet/face'
require 'puppet_x/vulnerability/selection'
require 'puppet_x/vulnerability/config'
require 'facter'

Puppet::Face.define(:vulnerability, '0.0.1') do
  extend Vulnerability::Selection
  extend Vulnerability::Config

  def self.print_summary(cve_list, level)
    selected_levels(level).each do |report_level|
      # rubocop: disable Style/FormatStringToken
      puts format('%-28s %-10s', "#{report_level} Vulnerabilities:", "#{cve_list.count { |_k, v| v['severity'] == report_level }} found.")
      # rubocop: enable Style/FormatStringToken
    end
  end

  action(:list) do
    default

    summary 'List detected vulnerabilities'

    description <<-DESC
    puppet-vulnerability
    ====================

    List detected vulnerabilities at a certain severity level and above.#{' '}

    Selected CVE's
    --------------
    When you only want to report on selected CVE's specify the CVE's you want to search for as parameters.

    Level
    -----
    You can specify the level you want to report on. By using the `--level` option. The known levels#{' '}
    in order of severity are:
    - Critical
    - High
    - Medium
    - Low
    - Negligible
    - Unknown

    When you don't specify a level, the default is 'High'. Meaning to list Critical and High CVE's.

    Allow List
    ----------
    When you know about certain CVE's and don;'t want to report on them, you can use the `--allow-list option`.
    When a vulnerability is found and it is on the allow-list, it is not reported.

    DESC

    option '--details', '-d' do
      summary 'List all known details of all found vulnerabilities'
      default_to { false }
    end

    option '--summary', '-s' do
      summary 'List a summary of all found vulnerabilities'
      default_to { false }
    end

    option '--level level', '-l level' do
      summary 'The minimum level of vulnerabilities.'
      default_to { 'High' }
      description <<-DESC
      The minimum level of vulnerabilities you want to report on. All
      found vulnerabilities with the specified level and gigher are reported.
      DESC
    end

    option '--allow-list id,id,id', '-a id,id,id' do
      summary 'The allowed vulnerabilities'
      default_to { '' }
      description <<-DESC
      The vulnerabilities you know and don't want to report.
      DESC
    end

    arguments '<cve_id> <cve_id>'

    when_invoked do |*arguments|
      #
      # First process all options
      #
      options         = arguments.pop
      level           = options[:level]
      allow_list      = options[:allow_list].split(',')
      details         = options[:details]
      summary         = options[:summary]
      #
      # Detect the input
      #
      vulnerabilities = Facter.value('cve_list')
      if vulnerabilities.nil?
        Puppet.err "cve_list fact not (yet) determined. No CVE's found yet."
        exit(1)
      end
      #
      # Check level
      #
      config_level = config_data[:level]
      unless selected_levels(config_level).include?(level)
        Puppet.warning "Requested reporting level '#{level}' lower than configured scanning level '#{config_level}'; reporting will not adequately report not scanned levels."
      end
      #
      # Do requested filtering
      #
      selected_cves = level_selection(vulnerabilities, level)
      selected_cves = filter_cves(selected_cves, allow_list)
      selected_cves = selected_cves.select { |c, _i| arguments.include?(c) } unless arguments.empty?
      if selected_cves.empty?
        exit 0
      else
        pp selected_cves if details
        print_summary(selected_cves, level) if summary
        exit 1
      end
    end
  end
end
